@@ -1,4 +1,4 @@
 from .components import Layer, Polygon
 from .device import Device
-from .mesh import generate_mesh, optimize_mesh
+from .mesh import generate_mesh, smooth_mesh
 from .transport import TransportDevice
