@@ -1,24 +1,23 @@
-import os
 import json
 import logging
-from copy import deepcopy
+import os
 from collections import defaultdict
 from contextlib import contextmanager
-from typing import Optional, Union, List, Tuple, Dict, Any
-import warnings
+from copy import deepcopy
+from typing import Any, Dict, List, Optional, Tuple, Union
 
 import dill
-import numpy as np
 import matplotlib.pyplot as plt
-from matplotlib.path import Path
-from matplotlib.patches import PathPatch
+import numpy as np
 import scipy.sparse as sp
+from matplotlib.patches import PathPatch
+from matplotlib.path import Path
 
 from .. import fem
-from ..units import ureg
 from ..parameter import Parameter
-from .components import Layer, Polygon
+from ..units import ureg
 from . import mesh
+from .components import Layer, Polygon
 
 logger = logging.getLogger(__name__)
 
@@ -446,7 +445,7 @@ class Device:
             origin: (x, y) coorindates of the origin.
 
         Returns:
-            The scaled :class:`superscreen.device.device.Device`.
+            The scaled :class:`superscreen.Device`.
         """
         if not (
             isinstance(origin, tuple)
@@ -469,7 +468,7 @@ class Device:
             origin: (x, y) coorindates of the origin.
 
         Returns:
-            The rotated :class:`superscreen.device.device.Device`.
+            The rotated :class:`superscreen.Device`.
         """
         if not (
             isinstance(origin, tuple)
@@ -492,7 +491,7 @@ class Device:
                 about which to mirror the layers.
 
         Returns:
-            The mirrored :class:`superscreen.device.device.Device`.
+            The mirrored :class:`superscreen.Device`.
         """
         device = self.copy(with_arrays=True, copy_arrays=True)
         for layer in device.layers.values():
@@ -555,10 +554,7 @@ class Device:
         convex_hull: bool = True,
         weight_method: str = "half_cotangent",
         min_points: Optional[int] = None,
-        optimesh_steps: Optional[int] = None,
-        optimesh_method: str = "cvt-block-diagonal",
-        optimesh_tolerance: float = 1e-3,
-        optimesh_verbose: bool = False,
+        smooth: int = 0,
         **meshpy_kwargs,
     ) -> None:
         """Generates and optimizes the triangular mesh.
@@ -572,11 +568,7 @@ class Device:
             min_points: Minimum number of vertices in the mesh. If None, then
                 the number of vertices will be determined by meshpy_kwargs and the
                 number of vertices in the underlying polygons.
-            optimesh_steps: Maximum number of optimesh steps. If None, then no
-                optimization is done.
-            optimesh_method: Name of the optimization method to use.
-            optimesh_tolerance: Optimesh quality tolerance.
-            optimesh_verbose: Whether to use verbose mode in optimesh.
+            smooth: Number of Laplacian smoothing iterations to perform.
             **meshpy_kwargs: Passed to meshpy.triangle.build().
         """
         logger.info("Generating mesh...")
@@ -592,25 +584,9 @@ class Device:
             boundary=boundary,
             **meshpy_kwargs,
         )
-        if optimesh_steps:
-            logger.info(f"Optimizing mesh with {points.shape[0]} vertices.")
-            try:
-                with warnings.catch_warnings():
-                    warnings.simplefilter("ignore", category=UserWarning)
-                    points, triangles = mesh.optimize_mesh(
-                        points,
-                        triangles,
-                        optimesh_steps,
-                        method=optimesh_method,
-                        tolerance=optimesh_tolerance,
-                        verbose=optimesh_verbose,
-                    )
-            except np.linalg.LinAlgError as e:
-                err = (
-                    "LinAlgError encountered in optimesh. Try reducing min_points "
-                    "or increasing the number of points in the device's important polygons."
-                )
-                raise RuntimeError(err) from e
+        if smooth:
+            logger.info(f"Smoothin mesh with {points.shape[0]} vertices.")
+            points, triangles = mesh.smooth_mesh(points, triangles, smooth)
         logger.info(
             f"Finished generating mesh with {points.shape[0]} points and "
             f"{triangles.shape[0]} triangles."
@@ -634,7 +610,7 @@ class Device:
                 or "inv_euclidian".
         """
 
-        from ..solve import C_vector, q_matrix, Q_matrix
+        from ..solve import C_vector, Q_matrix, q_matrix
 
         points = self.points
         triangles = self.triangles
@@ -763,7 +739,7 @@ class Device:
         legend: bool = True,
         figsize: Optional[Tuple[float, float]] = None,
         mesh: bool = False,
-        mesh_kwargs: Optional[Dict[str, Any]] = None,
+        mesh_kwargs: Dict[str, Any] = dict(color="k", lw=0.5),
         **kwargs,
     ) -> Tuple[plt.Figure, plt.Axes]:
         """Plot all of the device's polygons.
@@ -953,7 +929,7 @@ class Device:
                 handles = []
             j = 0
             for name, patch in patches[layer].items():
-                if name in exclude:
+                if name in exclude or name in self.holes:
                     continue
                 patch.set_facecolor(f"C{i}")
                 patch.set_alpha(alpha)
