@@ -5,6 +5,7 @@ import numpy as np
 import scipy.linalg as la
 import scipy.sparse as sp
 from matplotlib.path import Path
+from scipy.spatial.distance import cdist
 
 
 def in_polygon(
@@ -416,3 +417,28 @@ def gradient_vertices(
         gx[i, :] = np.einsum("i, ij -> j", weights, Gx[t, :])
         gy[i, :] = np.einsum("i, ij -> j", weights, Gy[t, :])
     return sp.csr_matrix(gx), sp.csr_matrix(gy)
+
+
+def cdist_batched(
+    XA: np.ndarray, XB: np.ndarray, *, batch_size: int = 0, **kwargs
+) -> np.ndarray:
+    """A batched version of scipy.spatial.distance.cdist.
+
+    The batching is performed over the second input array, XB. See the docs
+    for scipy.spatial.distance.cdist for keyword argument options.
+
+    Args:
+        XA: An mA by n array of mA original observations in an n-dimensional space.
+        XB: An mB by n array of mB original observations in an n-dimensional space.
+        batch_size: The maximum size of each batch of XB values.
+            Setting batch_size <= 0 results in no batching.
+
+    Returns:
+        An mA by mB distance matrix.
+    """
+    if "out" in kwargs:
+        raise ValueError("cdist_batched does not support the 'out' keyword argument.")
+    if batch_size <= 0:
+        return cdist(XA, XB, **kwargs)
+    batches = np.array_split(XB, range(batch_size, XB.shape[0], batch_size))
+    return np.concatenate([cdist(XA, batch) for batch in batches], axis=1)
