@@ -1,33 +1,22 @@
-import os
 import json
 import logging
+import os
 import zipfile
 from datetime import datetime
-from typing import (
-    Optional,
-    Union,
-    Callable,
-    Dict,
-    Tuple,
-    List,
-    Any,
-    NamedTuple,
-)
+from typing import Any, Callable, Dict, List, NamedTuple, Optional, Tuple, Union
 
 import dill
-import pint
-import numpy as np
 import matplotlib.pyplot as plt
+import numpy as np
+import pint
 from scipy import interpolate
-from scipy.spatial import distance
 
 from .about import version_dict
 from .device import Device, Polygon
-from .fem import in_polygon
+from .fem import cdist_batched, in_polygon
 from .parameter import Constant
 from .sources.current import biot_savart_2d
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -708,24 +697,26 @@ class Solution:
         # Compute the fields at the specified positions from the currents in each layer
         for name, layer in device.layers.items():
             if np.all((zs - layer.z0) == 0):
+                H = np.zeros_like(H_applied)
                 for film in device.films.values():
                     if film.layer == name and film.contains_points(positions).any():
                         raise ValueError(
                             "Use Solution.interp_fields() to interpolate "
                             "fields within a layer."
                         )
-            H = biot_savart_2d(
-                positions[:, 0],
-                positions[:, 1],
-                zs,
-                positions=points,
-                areas=device.weights,
-                current_densities=self.current_densities[name],
-                z0=layer.z0,
-                length_units=device.length_units,
-                current_units=self.current_units,
-                vector=vector,
-            )
+            else:
+                H = biot_savart_2d(
+                    positions[:, 0],
+                    positions[:, 1],
+                    zs,
+                    positions=points,
+                    areas=device.weights,
+                    current_densities=self.current_densities[name],
+                    z0=layer.z0,
+                    length_units=device.length_units,
+                    current_units=self.current_units,
+                    vector=vector,
+                )
             fields[name] = convert_field(
                 H,
                 units,
@@ -746,6 +737,7 @@ class Solution:
         units: Optional[str] = None,
         with_units: bool = True,
         return_sum: bool = True,
+        batch_size: int = 0,
     ) -> Union[np.ndarray, Dict[str, np.ndarray]]:
         """Calculates the vector potential due to currents in the device at any
         point(s) in space. Note that this only considers the vector potential
@@ -775,6 +767,8 @@ class Solution:
                 with units attached.
             return_sum: Whether to return the sum of the potential from all layers in
                 the device, or a dict of ``{layer_name: potential_from_layer}``.
+            batch_size: The maximum size of each batch of positions.
+                See :func:`superscreen.fem.cdist_batched`.
 
         Returns:
             An np.ndarray if return_sum is True, otherwise a dict of
@@ -807,9 +801,9 @@ class Solution:
         if zs.ndim == 1:
             # We need zs to be shape (m, 1)
             zs = zs[:, np.newaxis]
-        rho2 = distance.cdist(positions, points, metric="sqeuclidean").astype(
-            dtype, copy=False
-        )
+        rho2 = cdist_batched(
+            positions, points, batch_size=batch_size, metric="sqeuclidean"
+        ).astype(dtype, copy=False)
         # Compute the vector potential at the specified positions
         # from the currents in each layer
         vector_potentials = {}
